Images from FileSystem — LaVue 2.76.0 documentation

# Images from FileSystem

By pressing the Load button user can open the existing file.

For NeXus Files an additional dialog is displayed

- NeXus image fields: selects NeXus field

- Stacking dimension: dimension of the 3D field which enumerates the consecutive frames.

- Frame to display: an image frame of 3D field to be displayed, -1 means the last one.

NeXus image frames can be also changed by clicking on the slider/buttons nearby the Load button.